# | ~ Yvescmd >


|| ~> This library, created in a day, is based on the code of the microframework Cmd (which is, I believe, built-in).

# || ~> What's New:
- Updated the code for do_ commands. Now you can restrict them, and the number of arguments in the function matches the number of options in the command.
- Added void_ commands. They do not take any arguments at all.
- Removed non-working, unnecessary autocompletion functions.

# || ~$~> Future Enhancements:
- Add automated help (similar to the original module).
- Implement optional selection (it would be nice to implement this using arrow keys).

# pip install yvesCMD